/* remote-machine.c generated by valac 0.30.0, the Vala compiler
 * generated from remote-machine.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <libxml/uri.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_REMOTE_MACHINE (boxes_remote_machine_get_type ())
#define BOXES_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachine))
#define BOXES_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))
#define BOXES_IS_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_IS_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_REMOTE_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))

typedef struct _BoxesRemoteMachine BoxesRemoteMachine;
typedef struct _BoxesRemoteMachineClass BoxesRemoteMachineClass;
typedef struct _BoxesRemoteMachinePrivate BoxesRemoteMachinePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;

#define BOXES_TYPE_SPICE_DISPLAY (boxes_spice_display_get_type ())
#define BOXES_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay))
#define BOXES_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))
#define BOXES_IS_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_IS_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_SPICE_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))

typedef struct _BoxesSpiceDisplay BoxesSpiceDisplay;
typedef struct _BoxesSpiceDisplayClass BoxesSpiceDisplayClass;

#define BOXES_TYPE_VNC_DISPLAY (boxes_vnc_display_get_type ())
#define BOXES_VNC_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplay))
#define BOXES_VNC_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplayClass))
#define BOXES_IS_VNC_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VNC_DISPLAY))
#define BOXES_IS_VNC_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VNC_DISPLAY))
#define BOXES_VNC_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplayClass))

typedef struct _BoxesVncDisplay BoxesVncDisplay;
typedef struct _BoxesVncDisplayClass BoxesVncDisplayClass;
typedef struct _BoxesRemoteMachineConnectDisplayData BoxesRemoteMachineConnectDisplayData;

#define BOXES_TYPE_EDITABLE_STRING_PROPERTY (boxes_editable_string_property_get_type ())
#define BOXES_EDITABLE_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringProperty))
#define BOXES_EDITABLE_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringPropertyClass))
#define BOXES_IS_EDITABLE_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EDITABLE_STRING_PROPERTY))
#define BOXES_IS_EDITABLE_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EDITABLE_STRING_PROPERTY))
#define BOXES_EDITABLE_STRING_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringPropertyClass))

typedef struct _BoxesEditableStringProperty BoxesEditableStringProperty;
typedef struct _BoxesEditableStringPropertyClass BoxesEditableStringPropertyClass;
typedef struct _Block76Data Block76Data;

#define BOXES_TYPE_STRING_PROPERTY (boxes_string_property_get_type ())
#define BOXES_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringProperty))
#define BOXES_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))
#define BOXES_IS_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_IS_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_STRING_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))

typedef struct _BoxesStringProperty BoxesStringProperty;
typedef struct _BoxesStringPropertyClass BoxesStringPropertyClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _xmlFreeURI0(var) ((var == NULL) ? NULL : (var = (xmlFreeURI (var), NULL)))

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*update_status) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_suspend_at_exit) (BoxesMachine* self);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
	gboolean (*get_is_local) (BoxesMachine* self);
};

struct _BoxesRemoteMachine {
	BoxesMachine parent_instance;
	BoxesRemoteMachinePrivate * priv;
};

struct _BoxesRemoteMachineClass {
	BoxesMachineClass parent_class;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

typedef gint (*BoxesDisplayOpenFDFunc) (void* user_data);
struct _BoxesRemoteMachineConnectDisplayData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesRemoteMachine* self;
	BoxesMachineConnectFlags flags;
	BoxesDisplay* _tmp0_;
	BoxesDisplay* _tmp1_;
	BoxesDisplay* _tmp2_;
	BoxesDisplay* _tmp3_;
	BoxesDisplay* _tmp4_;
	BoxesDisplay* _tmp5_;
	BoxesDisplay* _tmp6_;
	BoxesDisplay* _tmp7_;
	GError * _inner_error_;
};

struct _Block76Data {
	int _ref_count_;
	BoxesRemoteMachine* self;
	BoxesEditableStringProperty* name_property;
};


static gpointer boxes_remote_machine_parent_class = NULL;
static BoxesIPropertiesProviderIface* boxes_remote_machine_boxes_iproperties_provider_parent_iface = NULL;

GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
GType boxes_remote_machine_get_type (void) G_GNUC_CONST;
enum  {
	BOXES_REMOTE_MACHINE_DUMMY_PROPERTY
};
BoxesRemoteMachine* boxes_remote_machine_new (BoxesCollectionSource* source, GError** error);
BoxesRemoteMachine* boxes_remote_machine_construct (GType object_type, BoxesCollectionSource* source, GError** error);
BoxesMachine* boxes_machine_construct (GType object_type, BoxesCollectionSource* source, const gchar* name, const gchar* uuid);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
void boxes_machine_set_state (BoxesMachine* self, BoxesMachineMachineState value);
void boxes_machine_load_screenshot (BoxesMachine* self);
static void boxes_remote_machine_update_info (BoxesRemoteMachine* self);
static void boxes_remote_machine_on_name_or_uri_changed (BoxesRemoteMachine* self);
static void _boxes_remote_machine_on_name_or_uri_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_display_get_type (void) G_GNUC_CONST;
static BoxesDisplay* boxes_remote_machine_create_display (BoxesRemoteMachine* self, GError** error);
BoxesSpiceDisplay* boxes_spice_display_new_with_uri (BoxesMachine* machine, BoxesBoxConfig* config, const gchar* uri);
BoxesSpiceDisplay* boxes_spice_display_construct_with_uri (GType object_type, BoxesMachine* machine, BoxesBoxConfig* config, const gchar* uri);
GType boxes_spice_display_get_type (void) G_GNUC_CONST;
GType boxes_vnc_display_get_type (void) G_GNUC_CONST;
BoxesVncDisplay* boxes_vnc_display_new_with_uri (BoxesBoxConfig* config, const gchar* _uri, GError** error);
BoxesVncDisplay* boxes_vnc_display_construct_with_uri (GType object_type, BoxesBoxConfig* config, const gchar* _uri, GError** error);
static void boxes_remote_machine_real_connect_display_data_free (gpointer _data);
static void boxes_remote_machine_real_connect_display (BoxesMachine* base, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_remote_machine_real_connect_display_co (BoxesRemoteMachineConnectDisplayData* _data_);
BoxesDisplay* boxes_machine_get_display (BoxesMachine* self);
void boxes_machine_set_display (BoxesMachine* self, BoxesDisplay* value);
void boxes_display_connect_it (BoxesDisplay* self, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target, GDestroyNotify open_fd_target_destroy_notify, GError** error);
void boxes_machine_show_display (BoxesMachine* self);
void boxes_display_set_enable_audio (BoxesDisplay* self, gboolean enable);
static GList* boxes_remote_machine_real_get_properties (BoxesIPropertiesProvider* base, BoxesPropertiesPage page, PropertyCreationFlag* flags);
GType boxes_editable_string_property_get_type (void) G_GNUC_CONST;
static Block76Data* block76_data_ref (Block76Data* _data76_);
static void block76_data_unref (void * _userdata_);
BoxesEditableStringProperty* boxes_iproperties_provider_add_editable_string_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, const gchar* value);
static void ___lambda63_ (BoxesRemoteMachine* self, BoxesEditableStringProperty* property, const gchar* name);
void boxes_collection_item_set_name (BoxesCollectionItem* self, const gchar* value);
static void ____lambda63__boxes_editable_string_property_changed (BoxesEditableStringProperty* _sender, const gchar* value, gpointer self);
static void ___lambda64_ (Block76Data* _data76_);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
void boxes_editable_string_property_set_text (BoxesEditableStringProperty* self, const gchar* value);
static void ____lambda64__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_string_property_get_type (void) G_GNUC_CONST;
BoxesStringProperty* boxes_iproperties_provider_add_string_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, const gchar* value);
gboolean boxes_machine_get_is_connected (BoxesMachine* self);
static void ____lambda65_ (BoxesRemoteMachine* self, BoxesEditableStringProperty* property, const gchar* uri);
static void _____lambda65__boxes_editable_string_property_changed (BoxesEditableStringProperty* _sender, const gchar* value, gpointer self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
GList* boxes_display_get_properties (BoxesDisplay* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
static void boxes_remote_machine_real_delete (BoxesMachine* base, gboolean by_user);
static void boxes_remote_machine_real_restart (BoxesMachine* base);
void boxes_machine_set_info (BoxesMachine* self, const gchar* value);


static void _boxes_remote_machine_on_name_or_uri_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_remote_machine_on_name_or_uri_changed ((BoxesRemoteMachine*) self);
#line 335 "remote-machine.c"
}


BoxesRemoteMachine* boxes_remote_machine_construct (GType object_type, BoxesCollectionSource* source, GError** error) {
	BoxesRemoteMachine * self = NULL;
	gboolean _tmp0_ = FALSE;
	BoxesCollectionSource* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	BoxesCollectionSource* _tmp16_ = NULL;
	BoxesCollectionSource* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	BoxesCollectionSource* _tmp21_ = NULL;
	BoxesBoxConfig* _tmp22_ = NULL;
	gint64 _tmp23_ = 0LL;
	BoxesCollectionSource* _tmp24_ = NULL;
	GError * _inner_error_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_return_val_if_fail (source != NULL, NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp1_ = source;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp2_ = boxes_collection_source_get_source_type (_tmp1_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp3_ = _tmp2_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp4_ = _tmp3_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp5_ = g_strcmp0 (_tmp4_, "spice") != 0;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_g_free0 (_tmp4_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	if (_tmp5_) {
#line 373 "remote-machine.c"
		BoxesCollectionSource* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp6_ = source;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp7_ = boxes_collection_source_get_source_type (_tmp6_);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp8_ = _tmp7_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp9_ = _tmp8_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp0_ = g_strcmp0 (_tmp9_, "vnc") != 0;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_g_free0 (_tmp9_);
#line 390 "remote-machine.c"
	} else {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp0_ = FALSE;
#line 394 "remote-machine.c"
	}
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	if (_tmp0_) {
#line 398 "remote-machine.c"
		BoxesCollectionSource* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		GError* _tmp14_ = NULL;
		GError* _tmp15_ = NULL;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp10_ = source;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp11_ = boxes_collection_source_get_uri (_tmp10_);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp12_ = _tmp11_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp13_ = _tmp12_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp14_ = g_error_new (BOXES_ERROR, BOXES_ERROR_INVALID, "source is not remote machine: %s", _tmp13_);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp15_ = _tmp14_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_g_free0 (_tmp13_);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_inner_error_ = _tmp15_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			g_propagate_error (error, _inner_error_);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_g_object_unref0 (self);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			return NULL;
#line 429 "remote-machine.c"
		} else {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			g_clear_error (&_inner_error_);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			return NULL;
#line 437 "remote-machine.c"
		}
	}
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp16_ = source;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp17_ = source;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp18_ = boxes_collection_source_get_name (_tmp17_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp19_ = _tmp18_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp20_ = _tmp19_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	self = (BoxesRemoteMachine*) boxes_machine_construct (object_type, _tmp16_, _tmp20_, NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_g_free0 (_tmp20_);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_RUNNING);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp21_ = source;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp21_, "name", (GObject*) self, "name", G_BINDING_BIDIRECTIONAL, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp22_ = ((BoxesMachine*) self)->config;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp23_ = g_get_real_time ();
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_box_config_set_access_last_time (_tmp22_, _tmp23_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_machine_load_screenshot ((BoxesMachine*) self);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_remote_machine_update_info (self);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_signal_connect_object ((GObject*) self, "notify::name", (GCallback) _boxes_remote_machine_on_name_or_uri_changed_g_object_notify, self, 0);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp24_ = source;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_signal_connect_object ((GObject*) _tmp24_, "notify::uri", (GCallback) _boxes_remote_machine_on_name_or_uri_changed_g_object_notify, self, 0);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	return self;
#line 478 "remote-machine.c"
}


BoxesRemoteMachine* boxes_remote_machine_new (BoxesCollectionSource* source, GError** error) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	return boxes_remote_machine_construct (BOXES_TYPE_REMOTE_MACHINE, source, error);
#line 485 "remote-machine.c"
}


static BoxesDisplay* boxes_remote_machine_create_display (BoxesRemoteMachine* self, GError** error) {
	BoxesDisplay* result = NULL;
	gchar* type = NULL;
	BoxesCollectionSource* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GQuark _tmp6_ = 0U;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	static GQuark _tmp5_label0 = 0;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	static GQuark _tmp5_label1 = 0;
#line 502 "remote-machine.c"
	GError * _inner_error_ = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp0_ = ((BoxesMachine*) self)->source;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp1_ = boxes_collection_source_get_source_type (_tmp0_);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp2_ = _tmp1_;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	type = _tmp2_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp3_ = type;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp4_ = _tmp3_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp6_ = (NULL == _tmp4_) ? 0 : g_quark_from_string (_tmp4_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	if (_tmp6_ == ((0 != _tmp5_label0) ? _tmp5_label0 : (_tmp5_label0 = g_quark_from_static_string ("spice")))) {
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		switch (0) {
#line 524 "remote-machine.c"
			default:
			{
				BoxesBoxConfig* _tmp7_ = NULL;
				BoxesCollectionSource* _tmp8_ = NULL;
				gchar* _tmp9_ = NULL;
				gchar* _tmp10_ = NULL;
				gchar* _tmp11_ = NULL;
				BoxesSpiceDisplay* _tmp12_ = NULL;
				BoxesDisplay* _tmp13_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp7_ = ((BoxesMachine*) self)->config;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp8_ = ((BoxesMachine*) self)->source;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp9_ = boxes_collection_source_get_uri (_tmp8_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp10_ = _tmp9_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp11_ = _tmp10_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp12_ = boxes_spice_display_new_with_uri ((BoxesMachine*) self, _tmp7_, _tmp11_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp13_ = (BoxesDisplay*) _tmp12_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_g_free0 (_tmp11_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				result = _tmp13_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_g_free0 (type);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				return result;
#line 556 "remote-machine.c"
			}
		}
	} else if (_tmp6_ == ((0 != _tmp5_label1) ? _tmp5_label1 : (_tmp5_label1 = g_quark_from_static_string ("vnc")))) {
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		switch (0) {
#line 562 "remote-machine.c"
			default:
			{
				BoxesVncDisplay* _tmp14_ = NULL;
				BoxesBoxConfig* _tmp15_ = NULL;
				BoxesCollectionSource* _tmp16_ = NULL;
				gchar* _tmp17_ = NULL;
				gchar* _tmp18_ = NULL;
				gchar* _tmp19_ = NULL;
				BoxesVncDisplay* _tmp20_ = NULL;
				BoxesVncDisplay* _tmp21_ = NULL;
				BoxesVncDisplay* _tmp22_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp15_ = ((BoxesMachine*) self)->config;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp16_ = ((BoxesMachine*) self)->source;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp17_ = boxes_collection_source_get_uri (_tmp16_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp18_ = _tmp17_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp19_ = _tmp18_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp20_ = boxes_vnc_display_new_with_uri (_tmp15_, _tmp19_, &_inner_error_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp21_ = _tmp20_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_g_free0 (_tmp19_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp14_ = _tmp21_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
					if (_inner_error_->domain == BOXES_ERROR) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
						g_propagate_error (error, _inner_error_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
						_g_free0 (type);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
						return NULL;
#line 602 "remote-machine.c"
					} else {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
						_g_free0 (type);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
						g_clear_error (&_inner_error_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
						return NULL;
#line 612 "remote-machine.c"
					}
				}
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp22_ = _tmp14_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp14_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				result = (BoxesDisplay*) _tmp22_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_g_object_unref0 (_tmp14_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_g_free0 (type);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				return result;
#line 627 "remote-machine.c"
			}
		}
	} else {
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		switch (0) {
#line 633 "remote-machine.c"
			default:
			{
				const gchar* _tmp23_ = NULL;
				gchar* _tmp24_ = NULL;
				gchar* _tmp25_ = NULL;
				GError* _tmp26_ = NULL;
				GError* _tmp27_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp23_ = type;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp24_ = g_strconcat ("unsupported display of type ", _tmp23_, NULL);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp25_ = _tmp24_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp26_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp25_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp27_ = _tmp26_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_g_free0 (_tmp25_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_inner_error_ = _tmp27_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				if (_inner_error_->domain == BOXES_ERROR) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
					g_propagate_error (error, _inner_error_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
					_g_free0 (type);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
					return NULL;
#line 663 "remote-machine.c"
				} else {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
					_g_free0 (type);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
					g_clear_error (&_inner_error_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
					return NULL;
#line 673 "remote-machine.c"
				}
			}
		}
	}
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_g_free0 (type);
#line 680 "remote-machine.c"
}


static void boxes_remote_machine_real_connect_display_data_free (gpointer _data) {
	BoxesRemoteMachineConnectDisplayData* _data_;
	_data_ = _data;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_g_object_unref0 (_data_->self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_slice_free (BoxesRemoteMachineConnectDisplayData, _data_);
#line 691 "remote-machine.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	return self ? g_object_ref (self) : NULL;
#line 698 "remote-machine.c"
}


static void boxes_remote_machine_real_connect_display (BoxesMachine* base, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesRemoteMachine * self;
	BoxesRemoteMachineConnectDisplayData* _data_;
	BoxesRemoteMachine* _tmp0_ = NULL;
	BoxesMachineConnectFlags _tmp1_ = 0;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	self = (BoxesRemoteMachine*) base;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_data_ = g_slice_new0 (BoxesRemoteMachineConnectDisplayData);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_remote_machine_real_connect_display);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_remote_machine_real_connect_display_data_free);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_data_->self = _tmp0_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp1_ = flags;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_data_->flags = _tmp1_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_remote_machine_real_connect_display_co (_data_);
#line 725 "remote-machine.c"
}


static void boxes_remote_machine_real_connect_display_finish (BoxesMachine* base, GAsyncResult* _res_, GError** error) {
	BoxesRemoteMachineConnectDisplayData* _data_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		return;
#line 735 "remote-machine.c"
	}
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 739 "remote-machine.c"
}


static gboolean boxes_remote_machine_real_connect_display_co (BoxesRemoteMachineConnectDisplayData* _data_) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	switch (_data_->_state_) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		case 0:
#line 748 "remote-machine.c"
		goto _state_0;
		default:
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		g_assert_not_reached ();
#line 753 "remote-machine.c"
	}
	_state_0:
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_data_->_tmp0_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_data_->_tmp0_ = boxes_machine_get_display ((BoxesMachine*) _data_->self);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_data_->_tmp1_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	if (_data_->_tmp1_ == NULL) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_data_->_tmp3_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_data_->_tmp3_ = boxes_remote_machine_create_display (_data_->self, &_data_->_inner_error_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_data_->_tmp2_ = _data_->_tmp3_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			g_error_free (_data_->_inner_error_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			if (_data_->_state_ == 0) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 782 "remote-machine.c"
			} else {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 786 "remote-machine.c"
			}
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			g_object_unref (_data_->_async_result);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			return FALSE;
#line 792 "remote-machine.c"
		}
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		boxes_machine_set_display ((BoxesMachine*) _data_->self, _data_->_tmp2_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_data_->_tmp4_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_data_->_tmp4_ = boxes_machine_get_display ((BoxesMachine*) _data_->self);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_data_->_tmp5_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_data_->_tmp5_ = _data_->_tmp4_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		boxes_display_connect_it (_data_->_tmp5_, NULL, NULL, NULL, &_data_->_inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			g_error_free (_data_->_inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_g_object_unref0 (_data_->_tmp2_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			if (_data_->_state_ == 0) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 818 "remote-machine.c"
			} else {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 822 "remote-machine.c"
			}
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			g_object_unref (_data_->_async_result);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			return FALSE;
#line 828 "remote-machine.c"
		}
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_g_object_unref0 (_data_->_tmp2_);
#line 832 "remote-machine.c"
	} else {
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		boxes_machine_show_display ((BoxesMachine*) _data_->self);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_data_->_tmp6_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_data_->_tmp6_ = boxes_machine_get_display ((BoxesMachine*) _data_->self);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_data_->_tmp7_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_data_->_tmp7_ = _data_->_tmp6_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		boxes_display_set_enable_audio (_data_->_tmp7_, TRUE);
#line 846 "remote-machine.c"
	}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	if (_data_->_state_ == 0) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 852 "remote-machine.c"
	} else {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 856 "remote-machine.c"
	}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_object_unref (_data_->_async_result);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	return FALSE;
#line 862 "remote-machine.c"
}


static Block76Data* block76_data_ref (Block76Data* _data76_) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_atomic_int_inc (&_data76_->_ref_count_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	return _data76_;
#line 871 "remote-machine.c"
}


static void block76_data_unref (void * _userdata_) {
	Block76Data* _data76_;
	_data76_ = (Block76Data*) _userdata_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	if (g_atomic_int_dec_and_test (&_data76_->_ref_count_)) {
#line 880 "remote-machine.c"
		BoxesRemoteMachine* self;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		self = _data76_->self;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_g_object_unref0 (_data76_->name_property);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_g_object_unref0 (self);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		g_slice_free (Block76Data, _data76_);
#line 890 "remote-machine.c"
	}
}


static void ___lambda63_ (BoxesRemoteMachine* self, BoxesEditableStringProperty* property, const gchar* name) {
	const gchar* _tmp0_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_return_if_fail (property != NULL);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_return_if_fail (name != NULL);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp0_ = name;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_collection_item_set_name ((BoxesCollectionItem*) self, _tmp0_);
#line 905 "remote-machine.c"
}


static void ____lambda63__boxes_editable_string_property_changed (BoxesEditableStringProperty* _sender, const gchar* value, gpointer self) {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	___lambda63_ ((BoxesRemoteMachine*) self, _sender, value);
#line 912 "remote-machine.c"
}


static void ___lambda64_ (Block76Data* _data76_) {
	BoxesRemoteMachine* self;
	BoxesEditableStringProperty* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	self = _data76_->self;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp0_ = _data76_->name_property;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp2_ = _tmp1_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_editable_string_property_set_text (_tmp0_, _tmp2_);
#line 931 "remote-machine.c"
}


static void ____lambda64__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	___lambda64_ (self);
#line 938 "remote-machine.c"
}


static void ____lambda65_ (BoxesRemoteMachine* self, BoxesEditableStringProperty* property, const gchar* uri) {
	BoxesCollectionSource* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_return_if_fail (property != NULL);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_return_if_fail (uri != NULL);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp0_ = ((BoxesMachine*) self)->source;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp1_ = uri;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_collection_source_set_uri (_tmp0_, _tmp1_);
#line 955 "remote-machine.c"
}


static void _____lambda65__boxes_editable_string_property_changed (BoxesEditableStringProperty* _sender, const gchar* value, gpointer self) {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	____lambda65_ ((BoxesRemoteMachine*) self, _sender, value);
#line 962 "remote-machine.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 969 "remote-machine.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_list_free (self);
#line 978 "remote-machine.c"
}


static GList* boxes_remote_machine_real_get_properties (BoxesIPropertiesProvider* base, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
	BoxesRemoteMachine * self;
	GList* result = NULL;
	GList* list = NULL;
	BoxesPropertiesPage _tmp0_ = 0;
	GError * _inner_error_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	self = (BoxesRemoteMachine*) base;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	list = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp0_ = page;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	switch (_tmp0_) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		case BOXES_PROPERTIES_PAGE_GENERAL:
#line 998 "remote-machine.c"
		{
			Block76Data* _data76_;
			BoxesEditableStringProperty* property = NULL;
			const gchar* _tmp1_ = NULL;
			BoxesCollectionSource* _tmp2_ = NULL;
			gchar* _tmp3_ = NULL;
			gchar* _tmp4_ = NULL;
			gchar* _tmp5_ = NULL;
			BoxesEditableStringProperty* _tmp6_ = NULL;
			BoxesEditableStringProperty* _tmp7_ = NULL;
			BoxesEditableStringProperty* _tmp8_ = NULL;
			BoxesEditableStringProperty* _tmp9_ = NULL;
			BoxesEditableStringProperty* _tmp10_ = NULL;
			const gchar* _tmp11_ = NULL;
			BoxesCollectionSource* _tmp12_ = NULL;
			gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			BoxesStringProperty* _tmp18_ = NULL;
			BoxesStringProperty* _tmp19_ = NULL;
			gboolean _tmp20_ = FALSE;
			gboolean _tmp21_ = FALSE;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_data76_ = g_slice_new0 (Block76Data);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_data76_->_ref_count_ = 1;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_data76_->self = g_object_ref (self);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp1_ = _ ("_Name");
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp2_ = ((BoxesMachine*) self)->source;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp3_ = boxes_collection_source_get_name (_tmp2_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp4_ = _tmp3_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp5_ = _tmp4_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp6_ = boxes_iproperties_provider_add_editable_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp1_, _tmp5_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp7_ = _tmp6_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_g_free0 (_tmp5_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			property = _tmp7_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp8_ = property;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			g_signal_connect_object (_tmp8_, "changed", (GCallback) ____lambda63__boxes_editable_string_property_changed, self, 0);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp9_ = property;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp10_ = _g_object_ref0 (_tmp9_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_data76_->name_property = _tmp10_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			g_signal_connect_data ((GObject*) self, "notify::name", (GCallback) ____lambda64__g_object_notify, block76_data_ref (_data76_), (GClosureNotify) block76_data_unref, 0);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp11_ = _ ("Protocol");
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp12_ = ((BoxesMachine*) self)->source;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp13_ = boxes_collection_source_get_source_type (_tmp12_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp14_ = _tmp13_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp15_ = _tmp14_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp16_ = g_utf8_strup (_tmp15_, (gssize) -1);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp17_ = _tmp16_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp18_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp11_, _tmp17_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp19_ = _tmp18_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_g_object_unref0 (_tmp19_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_g_free0 (_tmp17_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_g_free0 (_tmp15_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp20_ = boxes_machine_get_is_connected ((BoxesMachine*) self);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp21_ = _tmp20_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			if (_tmp21_) {
#line 1089 "remote-machine.c"
				const gchar* _tmp22_ = NULL;
				BoxesCollectionSource* _tmp23_ = NULL;
				gchar* _tmp24_ = NULL;
				gchar* _tmp25_ = NULL;
				gchar* _tmp26_ = NULL;
				BoxesStringProperty* _tmp27_ = NULL;
				BoxesStringProperty* _tmp28_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp22_ = _ ("URI");
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp23_ = ((BoxesMachine*) self)->source;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp24_ = boxes_collection_source_get_uri (_tmp23_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp25_ = _tmp24_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp26_ = _tmp25_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp27_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp22_, _tmp26_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp28_ = _tmp27_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_g_object_unref0 (_tmp28_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_g_free0 (_tmp26_);
#line 1115 "remote-machine.c"
			} else {
				const gchar* _tmp29_ = NULL;
				BoxesCollectionSource* _tmp30_ = NULL;
				gchar* _tmp31_ = NULL;
				gchar* _tmp32_ = NULL;
				gchar* _tmp33_ = NULL;
				BoxesEditableStringProperty* _tmp34_ = NULL;
				BoxesEditableStringProperty* _tmp35_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp29_ = _ ("_URI");
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp30_ = ((BoxesMachine*) self)->source;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp31_ = boxes_collection_source_get_uri (_tmp30_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp32_ = _tmp31_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp33_ = _tmp32_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp34_ = boxes_iproperties_provider_add_editable_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp29_, _tmp33_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_g_object_unref0 (property);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				property = _tmp34_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_g_free0 (_tmp33_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				_tmp35_ = property;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				g_signal_connect_object (_tmp35_, "changed", (GCallback) _____lambda65__boxes_editable_string_property_changed, self, 0);
#line 1146 "remote-machine.c"
			}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_g_object_unref0 (property);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			block76_data_unref (_data76_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_data76_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			break;
#line 1156 "remote-machine.c"
		}
		default:
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		break;
#line 1161 "remote-machine.c"
	}
	{
		BoxesDisplay* _tmp36_ = NULL;
		BoxesDisplay* _tmp37_ = NULL;
		BoxesDisplay* _tmp40_ = NULL;
		BoxesDisplay* _tmp41_ = NULL;
		BoxesPropertiesPage _tmp42_ = 0;
		GList* _tmp43_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp36_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp37_ = _tmp36_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		if (_tmp37_ == NULL) {
#line 1176 "remote-machine.c"
			BoxesDisplay* _tmp38_ = NULL;
			BoxesDisplay* _tmp39_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp39_ = boxes_remote_machine_create_display (self, &_inner_error_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_tmp38_ = _tmp39_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				if (_inner_error_->domain == BOXES_ERROR) {
#line 1187 "remote-machine.c"
					goto __catch73_boxes_error;
				}
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				__g_list_free__g_object_unref0_0 (list);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				g_clear_error (&_inner_error_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
				return NULL;
#line 1198 "remote-machine.c"
			}
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			boxes_machine_set_display ((BoxesMachine*) self, _tmp38_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
			_g_object_unref0 (_tmp38_);
#line 1204 "remote-machine.c"
		}
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp40_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp41_ = _tmp40_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp42_ = page;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp43_ = boxes_display_get_properties (_tmp41_, _tmp42_, flags);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		list = g_list_concat (list, _tmp43_);
#line 1216 "remote-machine.c"
	}
	goto __finally73;
	__catch73_boxes_error:
	{
		GError* _error_ = NULL;
		GError* _tmp44_ = NULL;
		const gchar* _tmp45_ = NULL;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_error_ = _inner_error_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_inner_error_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp44_ = _error_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp45_ = _tmp44_->message;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		g_warning ("remote-machine.vala:85: %s", _tmp45_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_g_error_free0 (_error_);
#line 1236 "remote-machine.c"
	}
	__finally73:
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		__g_list_free__g_object_unref0_0 (list);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		g_clear_error (&_inner_error_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		return NULL;
#line 1249 "remote-machine.c"
	}
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	result = list;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	return result;
#line 1255 "remote-machine.c"
}


static void boxes_remote_machine_real_delete (BoxesMachine* base, gboolean by_user) {
	BoxesRemoteMachine * self;
	gboolean _tmp0_ = FALSE;
	BoxesCollectionSource* _tmp1_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	self = (BoxesRemoteMachine*) base;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp0_ = by_user;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_return_if_fail (_tmp0_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp1_ = ((BoxesMachine*) self)->source;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_collection_source_delete (_tmp1_);
#line 1273 "remote-machine.c"
}


static void boxes_remote_machine_real_restart (BoxesMachine* base) {
	BoxesRemoteMachine * self;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	self = (BoxesRemoteMachine*) base;
#line 1281 "remote-machine.c"
}


static void boxes_remote_machine_update_info (BoxesRemoteMachine* self) {
	xmlURI* uri = NULL;
	BoxesCollectionSource* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	xmlURI* _tmp4_ = NULL;
	xmlURI* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	xmlURI* _tmp7_ = NULL;
	xmlURI* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_return_if_fail (self != NULL);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp0_ = ((BoxesMachine*) self)->source;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp1_ = boxes_collection_source_get_uri (_tmp0_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp2_ = _tmp1_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp3_ = _tmp2_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp4_ = xmlParseURI (_tmp3_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp5_ = _tmp4_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_g_free0 (_tmp3_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	uri = _tmp5_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp7_ = uri;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	if (_tmp7_ == NULL) {
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp6_ = TRUE;
#line 1321 "remote-machine.c"
	} else {
		xmlURI* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp8_ = uri;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp9_ = _tmp8_->server;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp10_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp11_ = _tmp10_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_tmp6_ = g_strcmp0 (_tmp9_, _tmp11_) == 0;
#line 1337 "remote-machine.c"
	}
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	if (_tmp6_) {
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		_xmlFreeURI0 (uri);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
		return;
#line 1345 "remote-machine.c"
	}
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp12_ = uri;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_tmp13_ = _tmp12_->server;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_machine_set_info ((BoxesMachine*) self, _tmp13_);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	_xmlFreeURI0 (uri);
#line 1355 "remote-machine.c"
}


static void boxes_remote_machine_on_name_or_uri_changed (BoxesRemoteMachine* self) {
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	g_return_if_fail (self != NULL);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_remote_machine_update_info (self);
#line 1364 "remote-machine.c"
}


static void boxes_remote_machine_class_init (BoxesRemoteMachineClass * klass) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_remote_machine_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	((BoxesMachineClass *) klass)->connect_display = boxes_remote_machine_real_connect_display;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	((BoxesMachineClass *) klass)->connect_display_finish = boxes_remote_machine_real_connect_display_finish;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	((BoxesMachineClass *) klass)->get_properties = boxes_remote_machine_real_get_properties;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	((BoxesMachineClass *) klass)->delete = boxes_remote_machine_real_delete;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	((BoxesMachineClass *) klass)->restart = boxes_remote_machine_real_restart;
#line 1381 "remote-machine.c"
}


static void boxes_remote_machine_boxes_iproperties_provider_interface_init (BoxesIPropertiesProviderIface * iface) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	boxes_remote_machine_boxes_iproperties_provider_parent_iface = g_type_interface_peek_parent (iface);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/remote-machine.vala"
	iface->get_properties = (GList* (*)(BoxesIPropertiesProvider*, BoxesPropertiesPage, PropertyCreationFlag*)) boxes_remote_machine_real_get_properties;
#line 1390 "remote-machine.c"
}


static void boxes_remote_machine_instance_init (BoxesRemoteMachine * self) {
}


GType boxes_remote_machine_get_type (void) {
	static volatile gsize boxes_remote_machine_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_remote_machine_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesRemoteMachineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_remote_machine_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesRemoteMachine), 0, (GInstanceInitFunc) boxes_remote_machine_instance_init, NULL };
		static const GInterfaceInfo boxes_iproperties_provider_info = { (GInterfaceInitFunc) boxes_remote_machine_boxes_iproperties_provider_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_remote_machine_type_id;
		boxes_remote_machine_type_id = g_type_register_static (BOXES_TYPE_MACHINE, "BoxesRemoteMachine", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_remote_machine_type_id, BOXES_TYPE_IPROPERTIES_PROVIDER, &boxes_iproperties_provider_info);
		g_once_init_leave (&boxes_remote_machine_type_id__volatile, boxes_remote_machine_type_id);
	}
	return boxes_remote_machine_type_id__volatile;
}



