/* empty-boxes.c generated by valac 0.30.0, the Vala compiler
 * generated from empty-boxes.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;
typedef struct _BoxesEmptyBoxesPrivate BoxesEmptyBoxesPrivate;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_WIZARD_WINDOW (boxes_wizard_window_get_type ())
#define BOXES_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindow))
#define BOXES_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))
#define BOXES_IS_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_IS_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_WIZARD_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))

typedef struct _BoxesWizardWindow BoxesWizardWindow;
typedef struct _BoxesWizardWindowClass BoxesWizardWindowClass;

#define BOXES_TYPE_PROPERTIES_WINDOW (boxes_properties_window_get_type ())
#define BOXES_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindow))
#define BOXES_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))
#define BOXES_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))

typedef struct _BoxesPropertiesWindow BoxesPropertiesWindow;
typedef struct _BoxesPropertiesWindowClass BoxesPropertiesWindowClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_ICOLLECTION_VIEW (boxes_icollection_view_get_type ())
#define BOXES_ICOLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ICOLLECTION_VIEW, BoxesICollectionView))
#define BOXES_IS_ICOLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ICOLLECTION_VIEW))
#define BOXES_ICOLLECTION_VIEW_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_ICOLLECTION_VIEW, BoxesICollectionViewIface))

typedef struct _BoxesICollectionView BoxesICollectionView;
typedef struct _BoxesICollectionViewIface BoxesICollectionViewIface;

#define BOXES_TYPE_SELECTION_CRITERIA (boxes_selection_criteria_get_type ())

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesEmptyBoxes {
	GtkStack parent_instance;
	BoxesEmptyBoxesPrivate * priv;
};

struct _BoxesEmptyBoxesClass {
	GtkStackClass parent_class;
};

struct _BoxesEmptyBoxesPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	GtkBox* grid_box;
	BoxesAppWindow* window;
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollection* collection;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesWizardWindow* wizard_window;
	BoxesPropertiesWindow* props_window;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesSelectionbar* selectionbar;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef enum  {
	BOXES_SELECTION_CRITERIA_ALL,
	BOXES_SELECTION_CRITERIA_NONE,
	BOXES_SELECTION_CRITERIA_RUNNING
} BoxesSelectionCriteria;

struct _BoxesICollectionViewIface {
	GTypeInterface parent_iface;
	void (*add_item) (BoxesICollectionView* self, BoxesCollectionItem* item);
	void (*remove_item) (BoxesICollectionView* self, BoxesCollectionItem* item);
	GList* (*get_selected_items) (BoxesICollectionView* self);
	void (*activate_first_item) (BoxesICollectionView* self);
	void (*select_by_criteria) (BoxesICollectionView* self, BoxesSelectionCriteria criteria);
	BoxesCollectionFilter* (*get_filter) (BoxesICollectionView* self);
	void (*set_filter) (BoxesICollectionView* self, BoxesCollectionFilter* value);
};

typedef void (*BoxesAppCallReadyFunc) (void* user_data);

static gpointer boxes_empty_boxes_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static BoxesUIIface* boxes_empty_boxes_boxes_ui_parent_iface = NULL;

GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
#define BOXES_EMPTY_BOXES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesPrivate))
enum  {
	BOXES_EMPTY_BOXES_DUMMY_PROPERTY,
	BOXES_EMPTY_BOXES_PREVIOUS_UI_STATE,
	BOXES_EMPTY_BOXES_UI_STATE
};
void boxes_empty_boxes_setup_ui (BoxesEmptyBoxes* self, BoxesAppWindow* window);
static void boxes_empty_boxes_on_app_ready (BoxesEmptyBoxes* self);
static void boxes_empty_boxes_update_visibility (BoxesEmptyBoxes* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
static void _boxes_empty_boxes_update_visibility_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void _boxes_empty_boxes_update_visibility_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
GType boxes_wizard_window_get_type (void) G_GNUC_CONST;
GType boxes_properties_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_selection_criteria_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_icollection_view_get_type (void) G_GNUC_CONST;
BoxesICollectionView* boxes_app_window_get_view (BoxesAppWindow* self);
BoxesEmptyBoxes* boxes_empty_boxes_new (void);
BoxesEmptyBoxes* boxes_empty_boxes_construct (GType object_type);
static GObject * boxes_empty_boxes_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
void boxes_app_call_when_ready (BoxesApp* self, BoxesAppCallReadyFunc func, void* func_target, GDestroyNotify func_target_destroy_notify);
static void _boxes_empty_boxes_on_app_ready_boxes_app_call_ready_func (gpointer self);
static void boxes_empty_boxes_finalize (GObject* obj);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void _vala_boxes_empty_boxes_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_empty_boxes_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static gpointer _g_object_ref0 (gpointer self) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	return self ? g_object_ref (self) : NULL;
#line 297 "empty-boxes.c"
}


void boxes_empty_boxes_setup_ui (BoxesEmptyBoxes* self, BoxesAppWindow* window) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_return_if_fail (self != NULL);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_return_if_fail (window != NULL);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp0_ = window;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_g_object_unref0 (self->priv->window);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self->priv->window = _tmp1_;
#line 316 "empty-boxes.c"
}


static void _boxes_empty_boxes_update_visibility_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	boxes_empty_boxes_update_visibility ((BoxesEmptyBoxes*) self);
#line 323 "empty-boxes.c"
}


static void _boxes_empty_boxes_update_visibility_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	boxes_empty_boxes_update_visibility ((BoxesEmptyBoxes*) self);
#line 330 "empty-boxes.c"
}


static void boxes_empty_boxes_on_app_ready (BoxesEmptyBoxes* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesCollection* _tmp1_ = NULL;
	BoxesApp* _tmp2_ = NULL;
	BoxesCollection* _tmp3_ = NULL;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_return_if_fail (self != NULL);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	boxes_empty_boxes_update_visibility (self);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp0_ = boxes_app_app;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp1_ = _tmp0_->collection;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_signal_connect_object (_tmp1_, "item-added", (GCallback) _boxes_empty_boxes_update_visibility_boxes_collection_item_added, self, 0);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp2_ = boxes_app_app;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp3_ = _tmp2_->collection;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_signal_connect_object (_tmp3_, "item-removed", (GCallback) _boxes_empty_boxes_update_visibility_boxes_collection_item_removed, self, 0);
#line 355 "empty-boxes.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_ = 0U;
#line 4442 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4442 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4442 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4442 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	return result;
#line 370 "empty-boxes.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_ = 0;
#line 4443 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4443 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4443 "/usr/share/vala-0.30/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 382 "empty-boxes.c"
}


static void boxes_empty_boxes_update_visibility (BoxesEmptyBoxes* self) {
	gboolean visible = FALSE;
	BoxesApp* _tmp0_ = NULL;
	BoxesCollection* _tmp1_ = NULL;
	GPtrArray* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	BoxesUIState _tmp11_ = 0;
	BoxesUIState _tmp12_ = 0;
	gboolean _tmp13_ = FALSE;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_return_if_fail (self != NULL);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp0_ = boxes_app_app;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp1_ = _tmp0_->collection;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp2_ = _tmp1_->items;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp3_ = g_ptr_array_get_length (_tmp2_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp4_ = _tmp3_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	visible = _tmp4_ == 0;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp6_ = visible;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	if (_tmp6_) {
#line 416 "empty-boxes.c"
		GtkWidget* _tmp7_ = NULL;
		GtkWidget* _tmp8_ = NULL;
		GtkBox* _tmp9_ = NULL;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp7_ = gtk_stack_get_visible_child ((GtkStack*) self);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp8_ = _tmp7_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp9_ = self->priv->grid_box;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp5_ = _tmp8_ != G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget);
#line 428 "empty-boxes.c"
	} else {
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp5_ = FALSE;
#line 432 "empty-boxes.c"
	}
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	if (_tmp5_) {
#line 436 "empty-boxes.c"
		GtkBox* _tmp10_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp10_ = self->priv->grid_box;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		gtk_stack_set_visible_child ((GtkStack*) self, (GtkWidget*) _tmp10_);
#line 442 "empty-boxes.c"
	}
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp11_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp12_ = _tmp11_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	if (_tmp12_ != BOXES_UI_STATE_COLLECTION) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		return;
#line 452 "empty-boxes.c"
	}
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp13_ = visible;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	if (_tmp13_) {
#line 458 "empty-boxes.c"
		BoxesAppWindow* _tmp14_ = NULL;
		GtkStack* _tmp15_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp14_ = self->priv->window;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp15_ = _tmp14_->below_bin;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		gtk_stack_set_visible_child_name (_tmp15_, "empty-boxes");
#line 467 "empty-boxes.c"
	} else {
		BoxesAppWindow* _tmp16_ = NULL;
		GtkStack* _tmp17_ = NULL;
		BoxesAppWindow* _tmp18_ = NULL;
		BoxesICollectionView* _tmp19_ = NULL;
		BoxesICollectionView* _tmp20_ = NULL;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp16_ = self->priv->window;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp17_ = _tmp16_->below_bin;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp18_ = self->priv->window;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp19_ = boxes_app_window_get_view (_tmp18_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp20_ = _tmp19_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		gtk_stack_set_visible_child (_tmp17_, (GtkWidget*) _tmp20_);
#line 486 "empty-boxes.c"
	}
}


BoxesEmptyBoxes* boxes_empty_boxes_construct (GType object_type) {
	BoxesEmptyBoxes * self = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self = (BoxesEmptyBoxes*) g_object_new (object_type, NULL);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	return self;
#line 497 "empty-boxes.c"
}


BoxesEmptyBoxes* boxes_empty_boxes_new (void) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	return boxes_empty_boxes_construct (BOXES_TYPE_EMPTY_BOXES);
#line 504 "empty-boxes.c"
}


static BoxesUIState boxes_empty_boxes_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesEmptyBoxes* self;
	BoxesUIState _tmp0_ = 0;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self = (BoxesEmptyBoxes*) base;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	result = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	return result;
#line 520 "empty-boxes.c"
}


static void boxes_empty_boxes_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesEmptyBoxes* self;
	BoxesUIState _tmp0_ = 0;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self = (BoxesEmptyBoxes*) base;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp0_ = value;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 535 "empty-boxes.c"
}


static BoxesUIState boxes_empty_boxes_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesEmptyBoxes* self;
	BoxesUIState _tmp0_ = 0;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self = (BoxesEmptyBoxes*) base;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp0_ = self->priv->_ui_state;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	result = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	return result;
#line 551 "empty-boxes.c"
}


static void boxes_empty_boxes_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesEmptyBoxes* self;
	BoxesUIState _tmp0_ = 0;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self = (BoxesEmptyBoxes*) base;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp0_ = value;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self->priv->_ui_state = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 566 "empty-boxes.c"
}


static void _boxes_empty_boxes_on_app_ready_boxes_app_call_ready_func (gpointer self) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	boxes_empty_boxes_on_app_ready ((BoxesEmptyBoxes*) self);
#line 573 "empty-boxes.c"
}


static GObject * boxes_empty_boxes_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesEmptyBoxes * self;
	BoxesApp* _tmp0_ = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	parent_class = G_OBJECT_CLASS (boxes_empty_boxes_parent_class);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp0_ = boxes_app_app;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	boxes_app_call_when_ready (_tmp0_, _boxes_empty_boxes_on_app_ready_boxes_app_call_ready_func, g_object_ref (self), g_object_unref);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	return obj;
#line 594 "empty-boxes.c"
}


static void boxes_empty_boxes_class_init (BoxesEmptyBoxesClass * klass) {
	gint BoxesEmptyBoxes_private_offset;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	boxes_empty_boxes_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_type_class_add_private (klass, sizeof (BoxesEmptyBoxesPrivate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_empty_boxes_get_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_empty_boxes_set_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_empty_boxes_constructor;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_empty_boxes_finalize;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EMPTY_BOXES_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EMPTY_BOXES_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	BoxesEmptyBoxes_private_offset = g_type_class_get_instance_private_offset (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/empty-boxes.ui");
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "grid_box", FALSE, BoxesEmptyBoxes_private_offset + G_STRUCT_OFFSET (BoxesEmptyBoxesPrivate, grid_box));
#line 622 "empty-boxes.c"
}


static void boxes_empty_boxes_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	boxes_empty_boxes_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	iface->get_previous_ui_state = boxes_empty_boxes_real_get_previous_ui_state;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	iface->set_previous_ui_state = boxes_empty_boxes_real_set_previous_ui_state;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	iface->get_ui_state = boxes_empty_boxes_real_get_ui_state;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	iface->set_ui_state = boxes_empty_boxes_real_set_ui_state;
#line 637 "empty-boxes.c"
}


static void boxes_empty_boxes_instance_init (BoxesEmptyBoxes * self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self->priv = BOXES_EMPTY_BOXES_GET_PRIVATE (self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 646 "empty-boxes.c"
}


static void boxes_empty_boxes_finalize (GObject* obj) {
	BoxesEmptyBoxes * self;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_g_object_unref0 (self->priv->grid_box);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_g_object_unref0 (self->priv->window);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	G_OBJECT_CLASS (boxes_empty_boxes_parent_class)->finalize (obj);
#line 660 "empty-boxes.c"
}


GType boxes_empty_boxes_get_type (void) {
	static volatile gsize boxes_empty_boxes_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_empty_boxes_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesEmptyBoxesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_empty_boxes_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesEmptyBoxes), 0, (GInstanceInitFunc) boxes_empty_boxes_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_empty_boxes_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_empty_boxes_type_id;
		boxes_empty_boxes_type_id = g_type_register_static (gtk_stack_get_type (), "BoxesEmptyBoxes", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_empty_boxes_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_empty_boxes_type_id__volatile, boxes_empty_boxes_type_id);
	}
	return boxes_empty_boxes_type_id__volatile;
}


static void _vala_boxes_empty_boxes_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesEmptyBoxes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		case BOXES_EMPTY_BOXES_PREVIOUS_UI_STATE:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		case BOXES_EMPTY_BOXES_UI_STATE:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		break;
#line 695 "empty-boxes.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		break;
#line 701 "empty-boxes.c"
	}
}


static void _vala_boxes_empty_boxes_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesEmptyBoxes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		case BOXES_EMPTY_BOXES_PREVIOUS_UI_STATE:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		case BOXES_EMPTY_BOXES_UI_STATE:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		break;
#line 723 "empty-boxes.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		break;
#line 729 "empty-boxes.c"
	}
}



